@@ -8,7 +8,12 @@ if (!is.data.frame(x) & !is.matrix(x)) pandterm("Input not a dataframe/matrix -
 if(rnd<0) pandterm("rnd must be > 0")
 if(!is.double(cutoff)) pandterm("cutoff must be a number")
 if(cutoff > 1 || cutoff < 0) pandterm("cutoff must be in (0,1)")
-mat=cor(x,use="complete.obs")
+if(is.matrix(x)) 
+    {numeric=apply(x,2,is.numeric)}
+else
+    {numeric=sapply(x,is.numeric)}
+xnum=x[,numeric]
+mat=cor(xnum,use="complete.obs")
 mat=round(mat,rnd)
 coln=colnames(mat)
 vmat=as.vector(mat)
@@ -19,7 +24,7 @@ cmat[cmat=="0"]=paste(rep(" ",rnd+3),collapse="")
 cmat[cmat=="1"]=paste(c("1.",rep("0",rnd)),collapse="")
 addsp=function(x){paste(" ",x,collapse="",sep="")}
 cmat[!neg]=sapply(cmat[!neg],addsp)                   # add a space in front of positive correlations for alignment
-cmat=matrix(cmat,ncol=ncol(x))
+cmat=matrix(cmat,ncol=ncol(xnum))
 colnames(cmat)=sapply(coln,addsp)
 rownames(cmat)=coln
 cat("Full Correlation Matrix",fill=TRUE)
